Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1340)

Unified Diff: Source/core/rendering/svg/RenderSVGRoot.cpp

Issue 246933007: Make <iframe> containing SVG behave as every other <iframe> (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Add NeedsRebaseline to test for landing Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/rendering/RenderReplaced.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/rendering/svg/RenderSVGRoot.cpp
diff --git a/Source/core/rendering/svg/RenderSVGRoot.cpp b/Source/core/rendering/svg/RenderSVGRoot.cpp
index 2bcce39c3b7ddd03243592c782635ff19d1ce801..f9a5801c5ea7cbfe3389dfb4787e582dc6da1dbc 100644
--- a/Source/core/rendering/svg/RenderSVGRoot.cpp
+++ b/Source/core/rendering/svg/RenderSVGRoot.cpp
@@ -106,8 +106,8 @@ bool RenderSVGRoot::isEmbeddedThroughFrameContainingSVGDocument() const
return false;
// If our frame has an owner renderer, we're embedded through eg. object/embed/iframe,
- // but we only negotiate if we're in an SVG document.
- if (!frame->ownerRenderer())
+ // but we only negotiate if we're in an SVG document inside a embedded object (object/embed).
+ if (!frame->ownerRenderer() || !frame->ownerRenderer()->isEmbeddedObject())
return false;
return frame->document()->isSVGDocument();
}
« no previous file with comments | « Source/core/rendering/RenderReplaced.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698